Changelog
=========

This file contains a brief summary of new features and dependency changes or
releases, in reverse chronological order.

v0.14.0
-------

- Dropped support for all Pythons < 3.6.
- Added support for Python 3.8 and 3.9.
- Added support for Django 3.1
- Improved documentation and started adding some typing hints.
- Added PayU provider.
- Pinned some dependencies to avoid potentially broken scenarios.
- Various code cleanups and minor issues fixed.

The project has also moved to Jazzband between the 0.13.0 and 0.14.0 releases.
The new project location is https://github.com/jazzband/django-payments.

PyPI packages and rtd locations remain the same.
